# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices.ArgsFile as ArgsFile
import GeoAPI.Util.ArgsFileUtil as ArgsFileUtil
import UI4.FormMaster.Editors.ConditionalHints as ConditionalHints
import PyUtilModule.Decorators as Decorators
import PyFnAttribute as FnAttribute
import UI4.FormMaster.GenericAssignParameterPolicy as GenericAssignParameterPolicy
import NodegraphAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.GenericAssignParameterPolicy_geolib3
import UI4.FormMaster.Editors.UserParametersDialogs as UserParametersDialogs
import Utils as Utils
import UI4.FormMaster.States as ValueState
from Nodes3DAPI.Material import ShaderPathComponents as ShaderPathComponents
from UI4.FormMaster.GenericAssignParameterPolicy_geolib3 import ClientIncomingValueSource as ClientIncomingValueSource, Geolib3GenericAssignPolicyDelegate as Geolib3GenericAssignPolicyDelegate, NullValue as NullValue
from UI4.Util.UndoGrouping import UndoContextGuard as UndoContextGuard
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MaterialClientIncomingValueSource(UI4.FormMaster.GenericAssignParameterPolicy_geolib3.ClientIncomingValueSource):
    class _WrenchMenuAction(PyQt5.QtWidgets.QAction):
        triggerWithData: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, text, parent, data) -> None: ...
        def _WrenchMenuAction__trigger(self): ...
    sActiveInterfaceEditors: ClassVar[set] = ...
    def __init__(self, port: NodegraphAPI.Port, attrRoot) -> None: ...
    def _MaterialClientIncomingValueSource__computeArgsFileEntriesForShaderOfType(self, shaderType): ...
    def _MaterialClientIncomingValueSource__editConditionalState(self, hintType, windowTitle, actionContext): ...
    def _MaterialClientIncomingValueSource__getDescriptionForShaderAttributeAtPath(self, attributePath): ...
    def _MaterialClientIncomingValueSource__getNameOfCurrentlySetShaderOfType(self, shaderType) -> str | None: ...
    def _MaterialClientIncomingValueSource__getRendererInfoPluginNameForShaderOfType(self, shaderType) -> str | None: ...
    def _MaterialClientIncomingValueSource__iterParameterNamesForShaderOfType(self, shaderType): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_editConditionalLockingOptions(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_editConditionalVisibility(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_editHelpText(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_editWidgetOptions(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_exportArgsFile(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_renameCoshader(self, actionContext): ...
    def _MaterialClientIncomingValueSource__on_wrenchMenu_widgetTypeTriggered(self, action): ...
    def _MaterialClientIncomingValueSource__refreshUI(self): ...
    def _MaterialClientIncomingValueSource__toggleInterfaceState(self, attributePath): ...
    def _appendToWrenchMenu(self, policy, attributePath, menu, pagePath: Incomplete | None = ...): ...
    def _closeButtonClicked(self, attrPath): ...
    def getHints(self, attributePath): ...
    def getPageHints(self, attributePath, pagePath): ...
    def isCloseButtonEnabled(self, policy, attrPath): ...
    def shouldDisplayClose(self, policy, attrPath): ...
    def shouldDisplayWrench(self, policy, attributePath): ...

class MaterialPolicyDelegateGeolib3(UI4.FormMaster.GenericAssignParameterPolicy_geolib3.Geolib3GenericAssignPolicyDelegate):
    def createPolicy(self, parentPolicy, param, paths: type[UI4.FormMaster.GenericAssignParameterPolicy_geolib3.NullValue] = ...): ...
    def getParamAttrPath(self, param): ...

class _NonpersistentShaderHintStore(PyQt5.QtCore.QObject):
    sSharedInstance: ClassVar[None] = ...
    shaderHintsDidChangeSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def getContainerHintsForShader(self, rendererInfoPluginName, shaderName, containerName): ...
    @classmethod
    def getInstance(cls): ...
    def getParameterHintsForShader(self, rendererInfoPluginName, shaderName, parameterName): ...
    def replaceHintsForShaderContainer(self, rendererInfoPluginName, shaderName, containerName, hints): ...
    def replaceHintsForShaderParameter(self, rendererInfoPluginName, shaderName, parameterName, hints): ...

def _ShaderParameterGroupNameForType(shaderType): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.App.Hotkeys as Hotkeys
import UI4.App.Icon as Icon
import PyUtilModule.KatanaFile as KatanaFile
import UI4.KatanaPrefs as KatanaPrefs
import UI4.App.KeyboardShortcutManager as KeyboardShortcutManager
import UI4.App.Layouts as Layouts
import NodegraphAPI as NodegraphAPI
import UI4.App.Preferences as Preferences
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.App.RecentFiles as RecentFiles
import UI4.App.TimelineWidget as TimelineWidget
import UI4 as UI4
import UI4.Widgets.BaseWidgets
import Utils as Utils
import typing
from UI4.Widgets.AssetIDLabel import AssetIDLabel as AssetIDLabel
from UI4.Widgets.BaseWidgets import BaseMainWindow as BaseMainWindow
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class KatanaWindow(UI4.Widgets.BaseWidgets.BaseMainWindow):
    _KatanaWindow__applicationShortcuts: ClassVar[dict] = ...
    groupWidgetClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _KatanaWindow__autoKeyAllTogglePressCallback(self): ...
    def _KatanaWindow__autoKeyAllToggleReleaseCallback(self): ...
    def _KatanaWindow__flushCachesKeyPressCallback(self): ...
    def _KatanaWindow__flushCachesKeyReleaseCallback(self): ...
    def _KatanaWindow__implicitResolversTogglePressCallback(self): ...
    def _KatanaWindow__implicitResolversToggleReleaseCallback(self): ...
    def _KatanaWindow__nextFrameKeyPressCallback(self): ...
    def _KatanaWindow__nextKeyKeyPressCallback(self): ...
    def _KatanaWindow__on_katana_fileDirty(self, eventType: str | None, state: int): ...
    def _KatanaWindow__on_nodegraph_changed(self, args: list[tuple[str, object, dict]]): ...
    def _KatanaWindow__openRecentFileKeyPressCallback(self, recentFileIndex): ...
    def _KatanaWindow__preferencesKeyPressCallback(self): ...
    def _KatanaWindow__previousFrameKeyPressCallback(self): ...
    def _KatanaWindow__previousKeyKeyPressCallback(self): ...
    def _KatanaWindow__redoKeyPressCallback(self): ...
    def _KatanaWindow__renderOnlySelectedTogglePressCallback(self): ...
    def _KatanaWindow__renderOnlySelectedToggleReleaseCallback(self): ...
    def _KatanaWindow__shelfActionsKeyPressCallback(self): ...
    def _KatanaWindow__undoKeyPressCallback(self): ...
    def closeEvent(self, event): ...
    @classmethod
    def formatAssetIDLabel(cls) -> str: ...
    @classmethod
    def formatWindowTitle(cls, tabTitles: Incomplete | None = ...) -> str: ...
    def getApplicationShortcuts(self, context: PyQt5.QtCore.Qt.ShortcutContext = ...) -> list: ...
    def getMainLayout(self): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar: ...
    def isTimelineVisible(self) -> bool: ...
    def populate(self): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
    def setTimelineVisible(self, timelineVisible: bool): ...
    def timeline(self): ...
    def updateAutosaveLabel(self, autoSave: bool = ...): ...
    def updateWindowTitleAndAssetIDLabel(self): ...

def CurrentMainWindow(): ...
def GetMainWindow() -> KatanaWindow: ...
def SetAssetIDLabelTextCallback(assetIDLabelTextCallback: typing.Callable): ...
def SetMainWindowTitleCallback(mainWindowTitleCallback: typing.Callable): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import UI4.NodeMaster.NodeInteractionDelegateManager
from typing import Set, Tuple

class AttributeEditorDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class PopupMenuOption(PyQt5.QtWidgets.QFrame):
    class DialogRequestButton(PyQt5.QtWidgets.QLabel):
        dialogRequest: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, *args) -> None: ...
        def _DialogRequestButton__emit(self): ...
        def enterEvent(self, ev): ...
        def leaveEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def mouseReleaseEvent(self, ev): ...

    class MenuLabel(PyQt5.QtWidgets.QLabel):
        activated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, *args) -> None: ...
        def _MenuLabel__emit(self): ...
        def enterEvent(self, ev): ...
        def leaveEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def mouseReleaseEvent(self, ev): ...
    def __init__(self, text, *args) -> None: ...
    def closePopupMenu(self): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.ConditionalHints as ConditionalHints
import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import UI4.Widgets.SortablePanel as SortablePanel
import UI4.Widgets.SortablePanel
from QT4FormWidgets.StringFormWidget import StringFormWidget
from UI4.Util.UndoGrouping import UndoGrouping as UndoGrouping
from typing import Set, Tuple

class OperationGroupEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def _OperationGroupEditor__addOperatorsToMenu(self, menu, names): ...
    def _getPanelForPolicy(self, vp): ...
    def buildAddMenu(self, menu): ...

class OperationPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, widgetFactory) -> None: ...

class PathNameString(StringFormWidget):
    def checkMimeData(self, data): ...
    def setMimeData(self, data, dropAction): ...

class TargetNameString(StringFormWidget):
    def checkMimeData(self, data): ...
    def setMimeData(self, data, dropAction): ...

def _IsValidMimeDrop(data): ...
def _checkIfPolicyIsPage(data): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.CameraCreate as CameraCreate
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.CameraCreate
import PyXmlIO as PyXmlIO
import Naming as UniqueName
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict
_Manipulator_XML: str

class LightNode3D(Nodes3DAPI.CameraCreate.CameraNode3D):
    def __init__(self) -> None: ...
    def AddGroup(self): ...
    def DeleteGroup(self, index): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def getCameraAttributes(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getCameraGeometry(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getCurveEditorNameHint(self, paramName): ...
    def getDefaultObjectName(self): ...
    def getExtraParameters(self): ...
    def getManipulatorAttributes(self, frameTime, presetAttrs): ...
    def getObjectType(self): ...
    def getOrCreateManipulatorGroup(self, preset, manipName, frameTime): ...
    def getRootAttr(self, objScenegraphLocation): ...
    def getViewerInfo(self, frameTime): ...
    def getWorldAttr(self, objScenegraphLocation, frameTime: Incomplete | None = ...): ...
    def setOverride(self, path, attrName, time, attrData, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.HintsDelegate as HintsDelegate
from typing import Set, Tuple

_DotNodeHints: dict
_TeleportHints: dict



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from RenderingAPI import FlushPluginCaches as FlushPluginCaches
from typing import Any, Set, Tuple, overload

kRenderMethodTypeDiskRender: str
kRenderMethodTypeLiveRender: str
kRenderMethodTypePreviewRender: str
kRenderPluginApiVersion: int
kRendererInfoApiVersion: int
kRendererObjectTypeDriver: str
kRendererObjectTypeFilter: str
kRendererObjectTypeOutputChannel: str
kRendererObjectTypeOutputChannelAttrHints: str
kRendererObjectTypeOutputChannelCustomParam: str
kRendererObjectTypeRenderOutput: str
kRendererObjectTypeShader: str
kRendererObjectValueTypeBoolean: int
kRendererObjectValueTypeByte: int
kRendererObjectValueTypeColor3: int
kRendererObjectValueTypeColor4: int
kRendererObjectValueTypeEnum: int
kRendererObjectValueTypeFloat: int
kRendererObjectValueTypeInt: int
kRendererObjectValueTypeLocation: int
kRendererObjectValueTypeMatrix: int
kRendererObjectValueTypeNormal: int
kRendererObjectValueTypePoint2: int
kRendererObjectValueTypePoint3: int
kRendererObjectValueTypePoint4: int
kRendererObjectValueTypePointer: int
kRendererObjectValueTypeShader: int
kRendererObjectValueTypeString: int
kRendererObjectValueTypeUint: int
kRendererObjectValueTypeUnknown: int
kRendererObjectValueTypeVector2: int
kRendererObjectValueTypeVector3: int
kRendererObjectValueTypeVector4: int
kRendererOutputTypeColor: str
kRendererOutputTypeDeep: str
kRendererOutputTypeForceNone: str
kRendererOutputTypeMerge: str
kRendererOutputTypePreScript: str
kRendererOutputTypeRaw: str
kRendererOutputTypeScript: str
kRendererOutputTypeShadow: str
kTerminalOpStateArgRenderMethodType: str
kTerminalOpStateArgSystem: str

class RendererInfoPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def addObjectLocation(self, type: str, location: str) -> None: ...
    def clearObjectLocations(self, type: str = ...) -> None: ...
    def getBatchRenderMethod(self) -> PyFnAttribute.GroupAttribute: ...
    def getLiveRenderTerminalOps(self, stateArgs: PyFnAttribute.GroupAttribute) -> list: ...
    def getRegisteredRendererName(self) -> str: ...
    def getRegisteredRendererVersion(self) -> str: ...
    def getRenderMethods(self) -> PyFnAttribute.GroupAttribute: ...
    def getRenderTerminalOps(self, stateArgs: PyFnAttribute.GroupAttribute) -> list: ...
    def getRendererCoshaderType(self) -> str: ...
    def getRendererObjectDefaultType(self, type: str) -> str: ...
    def getRendererObjectInfo(self, *args, **kwargs): ...
    @overload
    def getRendererObjectNames(self, type: str, typeTag: str) -> list[str]: ...
    @overload
    def getRendererObjectNames(self, type: str, typeTags: list[str] = ...) -> list[str]: ...
    def getRendererObjectTypes(self, type: str) -> list[str]: ...
    def getRendererShaderTypeTags(self, shaderType: str) -> list[str]: ...
    def getShaderInputNames(self, shader: str) -> list[str]: ...
    def getShaderInputTags(self, shader: str, inputName: str) -> list[str]: ...
    def getShaderOutputNames(self, shader: str) -> list[str]: ...
    def getShaderOutputTags(self, shader: str, outputName: str) -> list[str]: ...
    def isNodeTypeSupported(self, nodeType: str) -> bool: ...
    def isPolymeshFacesetSplittingEnabled(self) -> bool: ...
    def isPresetLocalFileNeeded(self, outputType: str) -> bool: ...
    def setKatanaPath(self, katanaPath: str) -> None: ...
    def setPluginPath(self, pluginPath: str) -> None: ...
    def setPluginRootPath(self, pluginPath: str) -> None: ...
    def setTmpPath(self, tmpPath: str) -> None: ...
    def setTypeTagNameFilter(self, filter: str, typeTag: str) -> None: ...

class RendererObjectInfo:
    def __init__(self, *args, **kwargs) -> None: ...
    def getContainerHints(self) -> PyFnAttribute.Attribute: ...
    def getFullPath(self) -> str: ...
    def getLocation(self) -> str: ...
    def getName(self) -> str: ...
    def getOutputType(self) -> int: ...
    def getParam(self, name: str) -> Any: ...
    def getParams(self) -> list: ...
    def getType(self) -> str: ...
    def getTypeTags(self) -> list[str]: ...

class RendererObjectParamInfo:
    def __init__(self, *args, **kwargs) -> None: ...
    def getArraySize(self) -> int: ...
    def getDefault(self) -> PyFnAttribute.Attribute: ...
    def getEnums(self) -> PyFnAttribute.Attribute: ...
    def getHints(self) -> PyFnAttribute.Attribute: ...
    def getName(self) -> str: ...
    def getType(self) -> int: ...

def GetPlugin(arg0: str) -> Any: ...
def ReleaseManager() -> None: ...
def _FlushPluginCaches() -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI_cmodule
import Nodes2DAPI_cmodule
from typing import Any, Set, Tuple, overload

NodeDehilightingModeConnected: int
NodeDehilightingModeContributing: int

def GetFontFile() -> str: ...
def angleVector2D(arg0: float, arg1: float, arg2: float, arg3: float) -> float: ...
def boundBoxBox(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float) -> tuple: ...
def insideVector2DBox(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> bool: ...
def intersectBoxBox(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float) -> tuple: ...
def intersectLineBox(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float) -> tuple: ...
def intersectLines(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float) -> Any: ...
def lengthVector2D(arg0: float, arg1: float) -> float: ...
def nodeShape_clearAllHiddenPortLinks() -> None: ...
def nodeShape_setPortLinkHidden(srcPort: NodegraphAPI_cmodule.Port, dstPort: NodegraphAPI_cmodule.Port, hidden: bool = ...) -> None: ...
def nodeWorld_addNode(node: NodegraphAPI_cmodule.Node, p: list[tuple[float, float]]) -> None: ...
def nodeWorld_draw(viewRoot: NodegraphAPI_cmodule.GroupNode, x: float, y: float) -> None: ...
def nodeWorld_drawFloatingLink(viewRoot: NodegraphAPI_cmodule.GroupNode, port: NodegraphAPI_cmodule.Port, x: float, y: float, viewScale: float) -> None: ...
def nodeWorld_drawPreselect(viewRoot: NodegraphAPI_cmodule.GroupNode, x: float, y: float, l: float, b: float, r: float, t: float, viewScale: float) -> None: ...
def nodeWorld_drawSelectedLink(viewRoot: NodegraphAPI_cmodule.GroupNode, portA: NodegraphAPI_cmodule.Port, portB: NodegraphAPI_cmodule.Port, viewScale: float, dimHead: bool = ..., dimTail: bool = ...) -> None: ...
def nodeWorld_drawSelectedPort(viewRoot: NodegraphAPI_cmodule.GroupNode, port: NodegraphAPI_cmodule.Port, viewScale: float) -> None: ...
def nodeWorld_drawShadow(l: float, b: float, r: float, t: float, w: float, o: float) -> None: ...
def nodeWorld_drawText(text: str) -> None: ...
def nodeWorld_findGroupNodeOfClick(viewRoot: NodegraphAPI_cmodule.Node, x: float, y: float, viewScale: float) -> Any: ...
def nodeWorld_flowText(text: str, lineWidth: float) -> list[str]: ...
def nodeWorld_getBounds(node: NodegraphAPI_cmodule.Node, useBasicDisplay: bool = ..., includeThumbnail: bool = ..., addPadding: bool = ...) -> tuple[float, float, float, float]: ...
def nodeWorld_getBoundsOfListOfNodes(nodes: list[NodegraphAPI_cmodule.Node], useBasicDisplay: bool = ..., addPadding: bool = ...) -> tuple[float, float, float, float]: ...
def nodeWorld_getChildBounds(viewRoot: NodegraphAPI_cmodule.GroupNode) -> tuple: ...
def nodeWorld_getFloatingOffset() -> tuple: ...
def nodeWorld_getGroupNodeRelativeAndAbsoluteChildScales(viewRoot: NodegraphAPI_cmodule.GroupNode, group: NodegraphAPI_cmodule.GroupNode, viewScale: float, x: float, y: float) -> tuple: ...
def nodeWorld_getLinkEndPoints(viewRoot: NodegraphAPI_cmodule.GroupNode, portA: NodegraphAPI_cmodule.Port, portB: NodegraphAPI_cmodule.Port, viewScale: float) -> tuple: ...
def nodeWorld_getNodeDehilitingMode() -> int: ...
def nodeWorld_getPortPosition(port: NodegraphAPI_cmodule.Port, viewScale: float) -> tuple: ...
def nodeWorld_getShapeAttrAsNumber(node: NodegraphAPI_cmodule.Node, attr: str) -> Any: ...
def nodeWorld_getShapeAttrAsString(node: NodegraphAPI_cmodule.Node, attr: str) -> Any: ...
def nodeWorld_hitTestBox(viewRoot: NodegraphAPI_cmodule.GroupNode, l: float, b: float, r: float, t: float, viewScale: float) -> list: ...
def nodeWorld_hitTestInset(group: NodegraphAPI_cmodule.GroupNode, x: float, y: float, viewScale: float) -> Any: ...
def nodeWorld_hitTestNode(viewRoot: NodegraphAPI_cmodule.GroupNode, node: NodegraphAPI_cmodule.Node, x: float, y: float, viewScale: float) -> Any: ...
def nodeWorld_hitTestPoint(viewRoot: NodegraphAPI_cmodule.GroupNode, x: float, y: float, viewScale: float) -> list: ...
def nodeWorld_isLargePortAreaEnabled() -> bool: ...
def nodeWorld_loadSceneIntoNodegraphSvgManager(id: str, path: str, opacity: float = ...) -> None: ...
def nodeWorld_mapFromWorldPositionToCurrentGroupWorldPosition(viewRoot: NodegraphAPI_cmodule.GroupNode, node: NodegraphAPI_cmodule.Node, x: float, y: float, viewScale: float) -> list: ...
def nodeWorld_measureText(text: str) -> tuple: ...
def nodeWorld_moveNode(node: NodegraphAPI_cmodule.Node, p: list[tuple[float, float]]) -> None: ...
def nodeWorld_refreshAllViewMaskLinkColors() -> None: ...
def nodeWorld_refreshAllViewMasks() -> None: ...
def nodeWorld_refreshNodeViewMaskFlags(node: NodegraphAPI_cmodule.Node) -> None: ...
def nodeWorld_removeNode(node: NodegraphAPI_cmodule.Node) -> None: ...
def nodeWorld_sceneIsLoadedIntoNodegraphSvgManager(id: str) -> bool: ...
def nodeWorld_setExpressionLinksEnabled(arg0: bool) -> None: ...
def nodeWorld_setFloatingOffset(groupNode: NodegraphAPI_cmodule.GroupNode, node: NodegraphAPI_cmodule.Node, x: float, y: float, viewScale: float) -> None: ...
def nodeWorld_setLargePortAreaEnabled(enabled: bool) -> None: ...
def nodeWorld_setLargePortAreaIncludeTypes(includeInput: bool, includeOutput: bool) -> None: ...
def nodeWorld_setLowContrastLookEnabled(arg0: bool) -> None: ...
def nodeWorld_setNodeActive(node: NodegraphAPI_cmodule.Node) -> None: ...
def nodeWorld_setNodeDehilitingEnabled(arg0: bool) -> None: ...
def nodeWorld_setNodeDehilitingMode(arg0: int) -> None: ...
def nodeWorld_setNodeState(node: NodegraphAPI_cmodule.Node, viewed: bool, edited: bool, selected: bool, floating: bool) -> None: ...
def nodeWorld_setNodeThumbnail(node: NodegraphAPI_cmodule.Node, thumbnail: Nodes2DAPI_cmodule.IntImage) -> None: ...
def nodeWorld_setNodeThumbnailEnabled(node: NodegraphAPI_cmodule.Node, enabled: bool) -> None: ...
def nodeWorld_setParent(node: NodegraphAPI_cmodule.Node, oldParent: NodegraphAPI_cmodule.GroupNode) -> None: ...
@overload
def nodeWorld_setShapeAttr(node: NodegraphAPI_cmodule.Node, attr: str, value: str) -> None: ...
@overload
def nodeWorld_setShapeAttr(node: NodegraphAPI_cmodule.Node, attr: str, value: float) -> None: ...
def nodeWorld_setShowNodeIcons(show: bool) -> None: ...
def nodeWorld_setViewMasksEnabled(enabled: bool) -> None: ...
def nodeWorld_shouldLargePortAreaIncludeInputPorts() -> bool: ...
def nodeWorld_shouldLargePortAreaIncludeOutputPorts() -> bool: ...
def nodeWorld_tranformPointToChildSpace(group: NodegraphAPI_cmodule.GroupNode, x: float, y: float, viewScale: float) -> tuple: ...
def nodeWorld_updateNodeHiliteTableWithIncomingNodes(node: NodegraphAPI_cmodule.Node) -> None: ...
def normalizeVector2D(arg0: float, arg1: float) -> tuple: ...
def scaleBoxVector2D(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> tuple: ...
def translateBoxVector2D(arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> tuple: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.NodeActionDelegate as NodeActionDelegate
import NodegraphAPI
import UI4 as UI4
from typing import Set, Tuple

def RegisterWrenchDelegate(nodeType, delegate): ...
def UpdateWrenchMenuWithDelegates(node: NodegraphAPI.Node, menu): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class OpaqueWidget(PyQt5.QtWidgets.QWidget):
    def paintEvent(self, event): ...

class WidgetHilightBox(PyQt5.QtCore.QObject):
    def __init__(self, target, width: int = ..., color: PyQt5.QtGui.QColor = ...) -> None: ...
    def hide(self): ...
    def setColor(self, color): ...
    def show(self): ...
    def snapToSize(self): ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

class BaseProxyLoader:
    @classmethod
    def createProxyAttr(cls, proxyFile: str, time: int, args: PyFnAttribute.GroupAttribute) -> PyFnAttribute.GroupAttribute: ...
    @classmethod
    def getFileExtensions(cls): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyXmlIO as PyXmlIO
import QT4Panels as QT4Panels
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Tabs as Tabs
import UI4 as UI4
import UI4.App.Tabs
import UI4.Tabs
import Utils as Utils
import typing
import weakref
from QT4Panels.PanelFrame import PanelFrame
from QT4Panels.PanelLayout import PanelLayout
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CornerWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent) -> None: ...

class EditLayoutsDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self) -> None: ...
    def _EditLayoutsDialog__on_deleteButton_clicked(self): ...
    def getDeleted(self): ...
    def getHotkeys(self): ...

class FloatingLayoutWidget(LayoutWidget):
    _RequireOneFrame: ClassVar[bool] = ...
    def __init__(self, layout: tuple = ..., size: Incomplete | None = ...) -> None: ...
    def _FloatingLayoutWidget__updateTitle(self, *args, **kwargs): ...
    def addNewFrame(self, *args, **kwargs): ...
    def closeEvent(self, event): ...
    def closeFrame(self, frame): ...
    def createPanelFrame(self, *args, **kwargs): ...
    def getPanelNames(self): ...
    def getTabTitles(self) -> list[str]: ...
    def leaveEvent(self, *args, **kwargs): ...
    def loadLayout(self, *args, **kwargs): ...

class LayoutFrame(PanelFrame):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _LayoutFrame__moveTabToDock(self, index: int, dockWidgetArea: PyQt5.QtCore.Qt.DockWidgetArea): ...
    def addTab(self, widget, label): ...
    def doCloseAll(self): ...
    def doCloseTab(self): ...
    def doDetachTab(self): ...
    def doShowTimeline(self, show): ...
    def doTabRightMouse(self, index): ...
    def doTabStartDrag(self, index): ...
    def getMinSize(self): ...
    def getTabTitles(self) -> list[str]: ...
    def insertTab(self, index, widget, label): ...
    def mousePressEvent(self, event): ...
    def removeTab(self, index): ...

class LayoutWidget(PanelLayout):
    _ActiveLayouts: ClassVar[weakref.WeakKeyDictionary] = ...
    _RequireOneFrame: ClassVar[bool] = ...
    _tabsToIgnore: ClassVar[set] = ...
    def __init__(self, parent, layout: tuple = ...) -> None: ...
    def createDetachLayout(self): ...
    def createPanelFrame(self, count, coords): ...
    def loadLayoutXml(self, element): ...
    def resetLayout(self): ...
    def saveLayoutXml(self): ...

class MainWindowFilter(PyQt5.QtCore.QObject):
    def eventFilter(self, window, event): ...

class ManualStateChangeManager(PyQt5.QtCore.QObject):
    def __init__(self) -> None: ...
    def resetStateChange(self): ...
    def setStateChanged(self, value): ...
    def stateChanged(self): ...

class SaveLayoutDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent) -> None: ...
    def _SaveLayoutDialog__on_combobox_editTextChanged(self, text): ...
    def accept(self): ...
    def getName(self): ...
    def getSaveDockWidgets(self) -> bool: ...
    def getSaveFloating(self): ...

def ActivateLayout(name: str, closeFloating: bool, closeDockWidgets: bool = ...): ...
def CreateFloatingTab(tabTypeName: str, size: Incomplete | None = ..., tabTitle: Incomplete | None = ...) -> UI4.App.Tabs.TabWithTimeline: ...
def CreateTabInFrame(tabTypeName: str, frame: LayoutFrame, tabTitle: Incomplete | None = ..., insertAtIndex: Incomplete | None = ...) -> UI4.App.Tabs.TabWithTimeline: ...
def DeleteUserLayouts(names: typing.Sequence[str]): ...
def GenerateLayoutImage(includeFloating, includeDockWidgets: bool) -> PyQt5.QtGui.QImage: ...
def GetDockWidgets(includeFloating: bool = ...) -> list[PyQt5.QtWidgets.QDockWidget]: ...
def GetFloatingWindows(): ...
def GetLayoutImage(name: str) -> PyQt5.QtGui.QImage | None: ...
def GetSystemLayouts(): ...
def GetTabs(tabTypeName: Incomplete | None = ..., includeFloating: bool = ..., includeDockWidgets: bool = ...) -> list[UI4.Tabs.BaseTab | PyQt5.QtWidgets.QWidget]: ...
def GetUserLayouts(): ...
def GetXmlLayout(includeFloating, includeDockWidgets: bool = ...): ...
def IsLayoutBeingActivated() -> bool: ...
def LoadLayoutFile(filename): ...
def NumScreens(): ...
def ResetLayout(includeFloating: bool, closeDockWidgets: bool = ...) -> list[UI4.App.Tabs.TabWithTimeline]: ...
def SaveUserLayout(name: str, includeFloating: bool, includeDockWidgets: bool): ...
def SaveUserLayouts(layouts: dict): ...
def SetFullScreen(value): ...
def SetXmlLayout(layoutElement): ...
def SwapScreens(): ...
def ToggleFullScreen(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Utils as Utils
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from _typeshed import Incomplete
from typing import Set, Tuple

def CreateLastFileSaveBookmark(): ...
def CreateScenegraphBookmark(bookmarkName: str, openSet: set[str], selectionSet: set[str], pinSet: set[str]): ...
def CreateWorkingSetsBookmark(bookmarkName: str, workingSetNames: Incomplete | None = ..., excludeWorkingSetNames: Incomplete | None = ..., bookmarkIfEmpty: bool = ...): ...
def DeleteScenegraphBookmark(bookmarkName: str): ...
def GetScenegraphBookmarkXML() -> str: ...
def GetScenegraphBookmarks() -> list[dict]: ...
def GetScenegraphFolders() -> list[str]: ...
def ImportScenegraphBookmarkXML(xml: str): ...
def LoadBookmark(bookmarkDict: dict, workingSetNames: Incomplete | None = ..., excludeWorkingSetNames: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import CatalogAPI.CatalogItem
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CatalogProgressWidget(ProgressWidget):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def GetProgressBarColors(catalogItem: CatalogAPI.CatalogItem.CatalogItem | None) -> None: ...
    def _CatalogProgressWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogProgressWidget__catalog_itemPropertyUpdate_cb(self, eventType, eventID, item): ...
    def _CatalogProgressWidget__update(self): ...
    def setCatalogItem(self, item): ...

class ProgressWidget(PyQt5.QtWidgets.QWidget):
    STATE_CANCELLED: ClassVar[int] = ...
    STATE_ERROR: ClassVar[int] = ...
    STATE_IN_PROGRESS: ClassVar[int] = ...
    STATE_NONE: ClassVar[int] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def GetProgressBarColors(state: int, indefinite: bool = ...) -> None: ...
    def getFraction(self) -> float: ...
    def getState(self) -> int: ...
    def isIndefinite(self) -> bool: ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setFraction(self, fraction: float): ...
    def setIndefinite(self, indefinite: bool): ...
    def setState(self, state: int): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import drawing_cmodule as DrawingModule
import Utils.EventModule as EventModule
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def CopyNodeColorToLinkColor(node: NodegraphAPI.Node): ...
def GetCustomNodeColor(node: NodegraphAPI.Node): ...
def HasCustomNodeColor(node: NodegraphAPI.Node): ...
def RemoveCustomNodeColor(node: NodegraphAPI.Node): ...
def SetCustomNodeColor(node: NodegraphAPI.Node, r, g, b): ...
